'---------------------------------------------------------------------
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
'KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'PARTICULAR PURPOSE.
'---------------------------------------------------------------------

Option Explicit On
Option Strict On

Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.ComponentModel.Design
Imports System.Diagnostics
Imports System.Drawing
Imports System.Drawing.Design
Imports System.Windows.Forms
Imports System.Windows.Forms.Design
Imports System.Windows.Forms.Design.Behavior

Imports DesignSurfaceExtenderLibrary.Extensions

Namespace ConvexHullDesignSurfaceExtension

    Public Class ConvexHullExtension
        Inherits DesignSurfaceExtension

        ' IReferenceService workaround.
        Private hullGlyph As ConvexHullGlyph

        Public Sub New(ByVal serviceProvider As IServiceProvider)
            MyBase.New(serviceProvider)
        End Sub

        Protected Overrides Sub PopulateAdorner(ByVal adorner As Adorner)
            adorner.Glyphs.Clear()

            hullGlyph = New ConvexHullGlyph( _
                Me.BehaviorService, _
                Me.ComponentChangeService, _
                Me.SelectionService, _
                Me.ReferenceService, _
                Me.ServiceProvider, _
                adorner)

            adorner.Glyphs.Add(hullGlyph)
        End Sub

        Protected Overrides Sub AddGlyphsForControl(ByVal control As Control)
            ' No implementation.
        End Sub

        Protected Overrides Sub RemoveGlyphsForControl(ByVal control As Control)
            ' IReferenceService workaround.
            If Me.hullGlyph IsNot Nothing Then
                Me.hullGlyph.ComputeGeometry(control)
            End If
        End Sub

        Public Overrides ReadOnly Property ActionList() As DesignerActionList
            Get
                If Me.actionListValue Is Nothing Then
                    Me.actionListValue = New ConvexHullActionList(Me)
                End If

                Return Me.actionListValue
            End Get
        End Property

    End Class

End Namespace
